==> clean900_2.0.1-8.tar.gz: clean900-2.0.1/usr/bin/clean900/update-en.sh <==
#!/bin/sh
#Update.sh
#version 2.0.0
#by incrys for www.maemomeego.net

if [ `id -u` != 0 ] ; then
    exec root <<EOF
exec sh $0 $*
EOF
	exit $?
fi 

conn=`ping -c 1 209.236.120.65 |grep 'received' | awk -F',' '{ print $2 }' | awk '{ print $1 }'`

if [ "$conn" != "0" ]
	then
		ric=`zenity --warning --title CleaN900 --text "You must have the active connection, preferably wifi. If you want to connect click OK, otherwise press out";echo $?`
			if [ "$ric" -eq 0 ]
				then
					dbus-send --system --type=method_call --dest=com.nokia.icd_ui /com/nokia/icd_ui com.nokia.icd_ui.show_conn_dlg boolean:false
					sleep 3
					dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Connection in progress... Please wait..."
					sleep 5
					apt-get update | zenity --title="Output Update" --text-info
					dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Update Completed"
				else
					dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Abort!"
			fi
	else
		apt-get update | zenity --title="Output Update" --text-info
		dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Update Completed"
fi

==> clean900_2.0.1-9.9.tar.gz: clean900-2.0.1/usr/bin/clean900/update-en.sh <==
#!/bin/sh
#Update.sh
#version 2.0.1-9.8
#by incrys for www.smartphonetab.net

if [ `id -u` != 0 ] ; then
    exec root <<EOF
exec sh $0 $*
EOF
	exit $?
fi 

conn=`ping -c 1 209.236.120.65 |grep 'received' | awk -F',' '{ print $2 }' | awk '{ print $1 }'`

if [ "$conn" != "0" ]
	then
		ric=`zenity --warning --title CleaN900 --text "You must have the active connection, preferably wifi. If you want to connect click OK, otherwise press out";echo $?`
			if [ "$ric" -eq 0 ]
				then
					dbus-send --system --type=method_call --dest=com.nokia.icd_ui /com/nokia/icd_ui com.nokia.icd_ui.show_conn_dlg boolean:false
					sleep 3
					dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Connection in progress... Please wait..."
					sleep 5
					apt-get update | zenity --title="Output Update" --text-info
					dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Update Completed"
				else
					dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Abort!"
			fi
	else
		apt-get update | zenity --title="Output Update" --text-info
		dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Update Completed"
fi
